tlslite.constants.AlertDescription

Package tlslite :: Module constants :: Class AlertDescription |
[hide private]
[frames] | no frames]

# Class AlertDescription

source code

Class Variables | [hide private]
| access_denied = `49`
| bad_certificate = `42`
| bad_record_mac = `20` A TLS record failed to decrypt properly.
| certificate_expired = `45`
| certificate_revoked = `44`
| certificate_unknown = `46`
| close_notify = `0`
| decode_error = `50`
| decompression_failure = `30`
| decrypt_error = `51`
| decryption_failed = `21`
| export_restriction = `60`
| handshake_failure = `40` A problem occurred while handshaking.
| illegal_parameter = `47`
| insufficient_security = `71`
| internal_error = `80`
| no_certificate = `41`
| no_renegotiation = `100`
| protocol_version = `70` The other party's SSL/TLS version was unacceptable.
| record_overflow = `22`
| unexpected_message = `10`
| unknown_ca = `48`
| unknown_psk_identity = `115`
| unsupported_certificate = `43`
| user_canceled = `90` The handshake is being cancelled for some reason.

Class Variable Details | [hide private]

  ### bad_record_mac A TLS record failed to decrypt properly. If this occurs during a SRP handshake it most likely indicates a bad password. It may also indicate an implementation error, or some tampering with the data in transit. This alert will be signalled by the server if the SRP password is bad. It may also be signalled by the server if the SRP username is unknown to the server, but it doesn't wish to reveal that fact. Value:
      20

  ### handshake_failure A problem occurred while handshaking. This typically indicates a lack of common ciphersuites between client and server, or some other disagreement (about SRP parameters or key sizes, for example). Value:
      40

  ### protocol_version The other party's SSL/TLS version was unacceptable. This indicates that the client and server couldn't agree on which version of SSL or TLS to use. Value:
      70